@@ -1,10 +1,11 @@
-AddCaseButton <- function(label="ADD"){
+AddCaseButton <- function(label=gettext("ADD", domain = "R-RQDA")){
   AddCasB <- gbutton(label,handler=function(h,...) {
-    CaseName <- ginput("Enter new Case Name. ", icon="info")
+    CaseName <- ginput(gettext("Enter new Case Name. ", domain = "R-RQDA"), icon="info")
     if (!is.na(CaseName)) {
       Encoding(CaseName) <- "UTF-8"
       AddCase(CaseName)
       CaseNamesUpdate()
+      enabled(button$profmatB) <- TRUE
       idx <- as.character(which(.rqda$.CasesNamesWidget[] %in%  CaseName) -1)
       ## note the position, before manipulation of items
       path <-gtkTreePathNewFromString(idx)
@@ -19,9 +20,9 @@ AddCaseButton <- function(label="ADD"){
 }
 
 
-DeleteCaseButton <- function(label="Delete"){
+DeleteCaseButton <- function(label=gettext("Delete", domain = "R-RQDA")){
   DelCasB <- gbutton(label, handler=function(h,...) {
-    del <- gconfirm("Really delete the Case?",icon="question")
+    del <- gconfirm(gettext("Really delete the Case?", domain = "R-RQDA"),icon="question")
     if (isTRUE(del)){
       SelectedCase <- svalue(.rqda$.CasesNamesWidget)
       Encoding(SelectedCase) <- "UTF-8"
@@ -43,13 +44,13 @@ DeleteCaseButton <- function(label="Delete"){
 }
 
 
-Case_RenameButton <- function(label="Rename",CaseNamesWidget=.rqda$.CasesNamesWidget,...)
+Case_RenameButton <- function(label=gettext("Rename", domain = "R-RQDA"),CaseNamesWidget=.rqda$.CasesNamesWidget,...)
 {
   ## rename of selected case.
   CasRenB <- gbutton(label,handler=function(h,...) {
     selectedCaseName <- svalue(CaseNamesWidget)
     ## get the new file names
-    NewName <- ginput("Enter new Case name. ", text=selectedCaseName, icon="info")
+    NewName <- ginput(gettext("Enter new Case name. ", domain = "R-RQDA"), text=selectedCaseName, icon="info")
     if (!is.na(NewName)){
       rename(selectedCaseName,NewName,"cases")
       CaseNamesUpdate()
@@ -62,7 +63,7 @@ Case_RenameButton <- function(label="Rename",CaseNamesWidget=.rqda$.CasesNamesWi
 }
 
 
-CaseMark_Button<-function(label="Mark"){
+CaseMark_Button<-function(label=gettext("Mark", domain = "R-RQDA")){
   CasMarB <- gbutton(label,handler=function(h,...) {
     MarkCaseFun()
     UpdateFileofCaseWidget()
@@ -97,7 +98,7 @@ MarkCaseFun <- function(){
         if (nrow(ExistLinkage)==0){
           ## if there are no relevant caselinkage, write the caselinkage table
           success <- dbWriteTable(.rqda$qdacon,"caselinkage",DAT,row.name=FALSE,append=TRUE)
-          if (!success) gmessage("Fail to write to database.")
+          if (!success) gmessage(gettext("Fail to write to database.", domain = "R-RQDA"))
         } else {
           Relations <- apply(ExistLinkage,1,FUN=function(x) relation(x[c("selfirst","selend")],c(ans$start,ans$end)))
           ExistLinkage$Relation <- sapply(Relations,FUN=function(x)x$Relation)
@@ -108,7 +109,7 @@ MarkCaseFun <- function(){
             ExistLinkage$End <- sapply(Relations,FUN=function(x)x$UnionIndex[2])
             if (all(ExistLinkage$Relation=="proximity")){
               success <- dbWriteTable(.rqda$qdacon,"caselinkage",DAT,row.name=FALSE,append=TRUE)
-              if (!success) gmessage("Fail to write to database.")
+              if (!success) gmessage(gettext("Fail to write to database.", domain = "R-RQDA"))
             } else {
               del1 <- ExistLinkage$WhichMin==2 & ExistLinkage$Relation =="inclusion"; del1[is.na(del1)] <- FALSE
               del2 <- ExistLinkage$Relation =="overlap"; del2[is.na(del2)] <- FALSE
@@ -124,7 +125,7 @@ MarkCaseFun <- function(){
                                 selfirst=Sel[1],selend=Sel[2],status=1,
                                 owner=.rqda$owner,date=date(),memo=memo)
               success <- dbWriteTable(.rqda$qdacon,"caselinkage",DAT,row.name=FALSE,append=TRUE)
-              if (!success) gmessage("Fail to write to database.")
+              if (!success) gmessage(gettext("Fail to write to database.", domain = "R-RQDA"))
             }
             }
             }
@@ -136,7 +137,7 @@ MarkCaseFun <- function(){
 }
 
 
-CaseUnMark_Button<-function(label="Unmark"){
+CaseUnMark_Button<-function(label=gettext("Unmark", domain = "R-RQDA")){
   CasUnMarB <- gbutton(label, handler=function(h,...) {
     con <- .rqda$qdacon
     W <- .rqda$.openfile_gui
@@ -145,7 +146,7 @@ CaseUnMark_Button<-function(label="Unmark"){
     ## if the not file is open, unmark doesn't work.
     if (!is.null(sel_index)) {
       SelectedCase <- svalue(.rqda$.CasesNamesWidget)
-      if (length(SelectedCase)==0) {gmessage("Select a case first.",con=TRUE)} else{
+      if (length(SelectedCase)==0) {gmessage(gettext("Select a case first.", domain = "R-RQDA"),con=TRUE)} else{
         SelectedCase <- enc(SelectedCase,"UTF-8")
         caseid <-  dbGetQuery(.rqda$qdacon,sprintf("select id from cases where name='%s'",SelectedCase))[,1]
         SelectedFile <- svalue(.rqda$.root_edit)
@@ -178,7 +179,7 @@ CaseUnMark_Button<-function(label="Unmark"){
   CasUnMarB
 }
 
-CaseAttribute_Button <- function(label="Attribute"){
+CaseAttribute_Button <- function(label=gettext("Attribute", domain = "R-RQDA")){
     CasAttrB <- gbutton(text=label, handler = function(h, ...) {
         SelectedCase <- svalue(.rqda$.CasesNamesWidget)
         if (length(SelectedCase!=0)){
@@ -193,224 +194,232 @@ CaseAttribute_Button <- function(label="Attribute"){
 
 prof_mat_Button <- function(label="prof_mat"){
   profmatB <- gbutton(text=label, handler = function(h, ...) {
-    prof_mat()
+    prof_mat(case_names = gselect.list(.rqda$.CasesNamesWidget[], multiple = TRUE, x= getOption("widgetCoordinate")[1]))
     })
   assign("profmatB", profmatB, envir=button)
   profmatB
 }
 
-CaseNamesWidgetMenu <- list()
-CaseNamesWidgetMenu$"Add File(s)"$handler <- function(h, ...) {
-  if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
-    SelectedCase <- svalue(.rqda$.CasesNamesWidget)
-    SelectedCase <- enc(SelectedCase,"UTF-8")
-    caseid <- dbGetQuery(.rqda$qdacon,sprintf("select id from cases where status=1 and name='%s'",SelectedCase))[,1]
-    freefile <-  dbGetQuery(.rqda$qdacon,"select name, id, file from source where status=1")
-    fileofcase <- dbGetQuery(.rqda$qdacon,sprintf("select fid from caselinkage where status=1 and caseid=%i",caseid))
-    Encoding(freefile[['name']]) <- Encoding(freefile[['file']]) <- "UTF-8"
-    if (nrow(fileofcase)!=0){
-      fileoutofcase <- subset(freefile,!(id %in% fileofcase$fid))
+GetCaseNamesWidgetMenu <- function()
+{
+  CaseNamesWidgetMenu <- list()
+  CaseNamesWidgetMenu[[gettext("Add File(s)", domain = "R-RQDA")]]$handler <- function(h, ...) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
+      SelectedCase <- svalue(.rqda$.CasesNamesWidget)
+      SelectedCase <- enc(SelectedCase,"UTF-8")
+      caseid <- dbGetQuery(.rqda$qdacon,sprintf("select id from cases where status=1 and name='%s'",SelectedCase))[,1]
+      freefile <-  dbGetQuery(.rqda$qdacon,"select name, id, file from source where status=1")
+      fileofcase <- dbGetQuery(.rqda$qdacon,sprintf("select fid from caselinkage where status=1 and caseid=%i",caseid))
+      Encoding(freefile[['name']]) <- Encoding(freefile[['file']]) <- "UTF-8"
+      if (nrow(fileofcase)!=0){
+        fileoutofcase <- subset(freefile,!(id %in% fileofcase$fid))
       } else  fileoutofcase <- freefile
-    if (length(fileoutofcase[['name']])==0) gmessage("All files are linked with this case.", cont=TRUE) else {
-      ##Selected <- select.list(fileoutofcase[['name']],multiple=TRUE)
-    CurrentFrame <- sys.frame(sys.nframe())
-    ## sys.frame(): get the frame of n
-    ## nframe(): get n of current frame
-    ## The value of them depends on where they evaluated, should not placed inside RunOnSelected()
-    RunOnSelected(fileoutofcase[['name']],multiple=TRUE,enclos=CurrentFrame,expr={
-      if (length(Selected)> 0) {
-        Encoding(Selected) <- "UTF-8"
-        fid <- fileoutofcase[fileoutofcase$name %in% Selected,"id"]
-        selend <- nchar(fileoutofcase[fileoutofcase$name %in% Selected,"file"])
-        Dat <- data.frame(caseid=caseid,fid=fid,selfirst=0,selend=selend,status=1,owner=.rqda$owner,date=date(),memo=NA)
-        dbWriteTable(.rqda$qdacon,"caselinkage",Dat,row.names=FALSE,append=TRUE)
-        UpdateFileofCaseWidget()
-      }})
-  }
-  }
-}
-
-CaseNamesWidgetMenu$"Add New File to Selected Case"$handler <- function(h, ...) {
-  AddNewFileFunOfCase()
-}
-
-CaseNamesWidgetMenu$"Case Memo"$handler <- function(h,...){
-  if (is_projOpen(envir=.rqda,conName="qdacon")) {
-    MemoWidget("Case",.rqda$.CasesNamesWidget,"cases")
-    ## see CodeCatButton.R  for definition of MemoWidget
-  }
-}
-CaseNamesWidgetMenu$"Show Cases with Memo Only"$handler <- function(h,...){
-  if (is_projOpen(envir=.rqda,conName="qdacon")) {
-   cnames <- RQDAQuery("select name from cases where memo is not null")$name
-   if (!is.null(cnames)) cnames <- enc(cnames,"UTF-8")
-   .rqda$.CasesNamesWidget[] <- cnames
-  }
-}
-CaseNamesWidgetMenu$"Add/modify Attributes..."$handler <- function(h,...){
-  if (is_projOpen(envir=.rqda,conName="qdacon")) {
-    SelectedCase <- svalue(.rqda$.CasesNamesWidget)
-    if (length(SelectedCase!=0)){
-    SelectedCase <- enc(SelectedCase,"UTF-8")
-    caseid <- dbGetQuery(.rqda$qdacon,sprintf("select id from cases where status=1 and name='%s'",SelectedCase))[,1]
-    CaseAttrFun(caseId=caseid,title=SelectedCase)
-  }
-}}
-CaseNamesWidgetMenu$"View Attributes"$handler <- function(h,...){
-  if (is_projOpen(envir=.rqda,conName="qdacon")) {
-   viewCaseAttr()
-  }
-}
-CaseNamesWidgetMenu$"Export Case Attributes"$handler <- function(h,...){
-    if (is_projOpen(envir=.rqda,conName="qdacon")) {
-        fName <- gfile(type='save',filter=list("csv"=list(pattern=c("*.csv"))))
-        Encoding(fName) <- "UTF-8"
-        if (length(grep(".csv$",fName))==0) fName <- sprintf("%s.csv",fName)
-        write.csv(GetAttr("case"), row.names=FALSE, file=fName, na="")
+      if (length(fileoutofcase[['name']])==0) gmessage(gettext("All files are linked with this case.", domain = "R-RQDA"), cont=TRUE) else {
+        ##Selected <- select.list(fileoutofcase[['name']],multiple=TRUE)
+        CurrentFrame <- sys.frame(sys.nframe())
+        ## sys.frame(): get the frame of n
+        ## nframe(): get n of current frame
+        ## The value of them depends on where they evaluated, should not placed inside RunOnSelected()
+        RunOnSelected(fileoutofcase[['name']],multiple=TRUE,enclos=CurrentFrame,expr={
+                        if (length(Selected)> 0) {
+                          Encoding(Selected) <- "UTF-8"
+                          fid <- fileoutofcase[fileoutofcase$name %in% Selected,"id"]
+                          selend <- nchar(fileoutofcase[fileoutofcase$name %in% Selected,"file"])
+                          Dat <- data.frame(caseid=caseid,fid=fid,selfirst=0,selend=selend,status=1,owner=.rqda$owner,date=date(),memo=NA)
+                          dbWriteTable(.rqda$qdacon,"caselinkage",Dat,row.names=FALSE,append=TRUE)
+                          UpdateFileofCaseWidget()
+    }})
+      }
     }
-}
-CaseNamesWidgetMenu$"Sort All by Created Time"$handler <- function(h,...){
-  CaseNamesUpdate(.rqda$.CasesNamesWidget,sortByTime = TRUE)
-}
-CaseNamesWidgetMenu$"Web Search"$Google$handler <- function(h,...){
-  KeyWord <- svalue(.rqda$.CasesNamesWidget)
-  if (length(KeyWord)!=0){
-    KeyWord <- iconv(KeyWord, from="UTF-8")
-    browseURL(sprintf("http://www.google.com/search?q=%s",KeyWord))
   }
-}
-CaseNamesWidgetMenu$"Web Search"$Yahoo$handler <- function(h,...){
-  KeyWord <- svalue(.rqda$.CasesNamesWidget)
-  if (length(KeyWord)!=0){
-    KeyWord <- iconv(KeyWord, from="UTF-8")
-    browseURL(sprintf("http://search.yahoo.com/search;_ylt=A0oGkmFV.CZJNssAOK.l87UF?p=%s&ei=UTF-8&iscqry=&fr=sfp&fr2=sfp"
-                      ,KeyWord))
+
+  CaseNamesWidgetMenu[[gettext("Add New File to Selected Case", domain = "R-RQDA")]]$handler <- function(h, ...) {
+    AddNewFileFunOfCase()
   }
-}
-CaseNamesWidgetMenu$"Web Search"$Baidu$handler <- function(h,...){
-  KeyWord <- svalue(.rqda$.CasesNamesWidget)
-  if (length(KeyWord)!=0){
-    KeyWord <- iconv(KeyWord, from="UTF-8",to="CP936") ## should be in CP936 to work properly.
-    browseURL(sprintf("http://www.baidu.com/s?wd=%s",paste("%",paste(charToRaw(KeyWord),sep="",collapse="%"),sep="",collapse="")))
+
+  CaseNamesWidgetMenu[[gettext("Case Memo", domain = "R-RQDA")]]$handler <- function(h,...){
+    if (is_projOpen(envir=.rqda,conName="qdacon")) {
+      MemoWidget(gettext("Case", domain = "R-RQDA"),.rqda$.CasesNamesWidget,"cases")
+      ## see CodeCatButton.R  for definition of MemoWidget
+    }
   }
-}
-CaseNamesWidgetMenu$"Web Search"$Sogou$handler <- function(h,...){
-  KeyWord <- svalue(.rqda$.CasesNamesWidget)
-  if (length(KeyWord)!=0){
-    KeyWord <- iconv(KeyWord, from="UTF-8",to="CP936")## should be in CP936 to work properly.
-    browseURL(sprintf("http://www.sogou.com/sohu?query=%s",paste("%",paste(charToRaw(KeyWord),sep="",collapse="%"),sep="",collapse="")))
+  CaseNamesWidgetMenu[[gettext("Show Cases with Memo Only", domain = "R-RQDA")]]$handler <- function(h,...){
+    if (is_projOpen(envir=.rqda,conName="qdacon")) {
+      cnames <- RQDAQuery("select name from cases where memo is not null")$name
+      if (!is.null(cnames)) cnames <- enc(cnames,"UTF-8")
+      .rqda$.CasesNamesWidget[] <- cnames
+    }
   }
+  CaseNamesWidgetMenu[[gettext("Add/modify Attributes...", domain = "R-RQDA")]]$handler <- function(h,...){
+    if (is_projOpen(envir=.rqda,conName="qdacon")) {
+      SelectedCase <- svalue(.rqda$.CasesNamesWidget)
+      if (length(SelectedCase!=0)){
+        SelectedCase <- enc(SelectedCase,"UTF-8")
+        caseid <- dbGetQuery(.rqda$qdacon,sprintf("select id from cases where status=1 and name='%s'",SelectedCase))[,1]
+        CaseAttrFun(caseId=caseid,title=SelectedCase)
+      }
+  }}
+  CaseNamesWidgetMenu[[gettext("View Attributes", domain = "R-RQDA")]]$handler <- function(h,...){
+    if (is_projOpen(envir=.rqda,conName="qdacon")) {
+      viewCaseAttr()
+    }
+  }
+  CaseNamesWidgetMenu[[gettext("Export Case Attributes", domain = "R-RQDA")]]$handler <- function(h,...){
+    if (is_projOpen(envir=.rqda,conName="qdacon")) {
+      fName <- gfile(type='save',filter=list("csv"=list(pattern=c("*.csv"))))
+      Encoding(fName) <- "UTF-8"
+      if (length(grep(".csv$",fName))==0) fName <- sprintf("%s.csv",fName)
+      write.csv(GetAttr("case"), row.names=FALSE, file=fName, na="")
+    }
+  }
+  CaseNamesWidgetMenu[[gettext("Sort All by Created Time", domain = "R-RQDA")]]$handler <- function(h,...){
+    CaseNamesUpdate(.rqda$.CasesNamesWidget,sortByTime = TRUE)
+  }
+  CaseNamesWidgetMenu[[gettext("Web Search", domain = "R-RQDA")]]$Google$handler <- function(h,...){
+    KeyWord <- svalue(.rqda$.CasesNamesWidget)
+    if (length(KeyWord)!=0){
+      KeyWord <- iconv(KeyWord, from="UTF-8")
+      browseURL(sprintf("http://www.google.com/search?q=%s",KeyWord))
+    }
+  }
+  CaseNamesWidgetMenu[[gettext("Web Search", domain = "R-RQDA")]]$Yahoo$handler <- function(h,...){
+    KeyWord <- svalue(.rqda$.CasesNamesWidget)
+    if (length(KeyWord)!=0){
+      KeyWord <- iconv(KeyWord, from="UTF-8")
+      browseURL(sprintf("http://search.yahoo.com/search;_ylt=A0oGkmFV.CZJNssAOK.l87UF?p=%s&ei=UTF-8&iscqry=&fr=sfp&fr2=sfp"
+                        ,KeyWord))
+    }
+  }
+  CaseNamesWidgetMenu[[gettext("Web Search", domain = "R-RQDA")]]$Baidu$handler <- function(h,...){
+    KeyWord <- svalue(.rqda$.CasesNamesWidget)
+    if (length(KeyWord)!=0){
+      KeyWord <- iconv(KeyWord, from="UTF-8",to="CP936") ## should be in CP936 to work properly.
+      browseURL(sprintf("http://www.baidu.com/s?wd=%s",paste("%",paste(charToRaw(KeyWord),sep="",collapse="%"),sep="",collapse="")))
+    }
+  }
+  CaseNamesWidgetMenu[[gettext("Web Search", domain = "R-RQDA")]]$Sogou$handler <- function(h,...){
+    KeyWord <- svalue(.rqda$.CasesNamesWidget)
+    if (length(KeyWord)!=0){
+      KeyWord <- iconv(KeyWord, from="UTF-8",to="CP936")## should be in CP936 to work properly.
+      browseURL(sprintf("http://www.sogou.com/sohu?query=%s",paste("%",paste(charToRaw(KeyWord),sep="",collapse="%"),sep="",collapse="")))
+    }
+  }
+  CaseNamesWidgetMenu
 }
 
 
 ## pop-up menu of .rqda$.FileofCase
-FileofCaseWidgetMenu <- list() ## not used yet.
-FileofCaseWidgetMenu$"Add To File Category ..."$handler <- function(h, ...) {
-  if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
-    AddToFileCategory(Widget=.rqda$.FileofCase,updateWidget=FALSE)
+GetFileofCaseWidgetMenu <- function()
+{
+  FileofCaseWidgetMenu <- list() ## not used yet.
+  FileofCaseWidgetMenu[[gettext("Add To File Category ...", domain = "R-RQDA")]]$handler <- function(h, ...) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
+      AddToFileCategory(Widget=.rqda$.FileofCase,updateWidget=FALSE)
+    }
   }
-}
-FileofCaseWidgetMenu$"Drop Selected File(s)"$handler <- function(h, ...) {
-  if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
-    FileOfCat <- svalue(.rqda$.FileofCase)
-    if ((NumofSelected <- length(FileOfCat)) ==0) {
-      gmessage("Please select the Files you want to delete.",con=TRUE)} else
-    {
-      ## Give a confirm msg
-      del <- gconfirm(sprintf("Delete %i file(s) from this category. Are you sure?",NumofSelected),con=TRUE,icon="question")
-      if (isTRUE(del)){
-        SelectedCase <- svalue(.rqda$.CasesNamesWidget)
-        ## Encoding(SelectedCase) <- Encoding(FileOfCat)<- "UTF-8"
-        SelectedCase <- enc(SelectedCase,"UTF-8")
-        FileOfCat <- enc(FileOfCat,"UTF-8")
-        caseid <- dbGetQuery(.rqda$qdacon,sprintf("select id from cases where status=1 and name='%s'",SelectedCase))[,1]
-        for (i in FileOfCat){
-          fid <- dbGetQuery(.rqda$qdacon,sprintf("select id from source where status=1 and name='%s'",i))[,1]
-          dbGetQuery(.rqda$qdacon,sprintf("update caselinkage set status=0 where caseid=%i and fid=%i",caseid,fid))
+  FileofCaseWidgetMenu[[gettext("Drop Selected File(s)", domain = "R-RQDA")]]$handler <- function(h, ...) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
+      FileOfCat <- svalue(.rqda$.FileofCase)
+      if ((NumofSelected <- length(FileOfCat)) ==0) {
+        gmessage(gettext("Please select the Files you want to delete.", domain = "R-RQDA"),con=TRUE)} else
+        {
+          ## Give a confirm msg
+          del <- gconfirm(sprintf(gettext("Delete %i file(s) from this category. Are you sure?", domain = "R-RQDA"),NumofSelected),con=TRUE,icon="question")
+          if (isTRUE(del)){
+            SelectedCase <- svalue(.rqda$.CasesNamesWidget)
+            ## Encoding(SelectedCase) <- Encoding(FileOfCat)<- "UTF-8"
+            SelectedCase <- enc(SelectedCase,"UTF-8")
+            FileOfCat <- enc(FileOfCat,"UTF-8")
+            caseid <- dbGetQuery(.rqda$qdacon,sprintf("select id from cases where status=1 and name='%s'",SelectedCase))[,1]
+            for (i in FileOfCat){
+              fid <- dbGetQuery(.rqda$qdacon,sprintf("select id from source where status=1 and name='%s'",i))[,1]
+              dbGetQuery(.rqda$qdacon,sprintf("update caselinkage set status=0 where caseid=%i and fid=%i",caseid,fid))
+            }
+            ## update Widget
+            UpdateFileofCaseWidget()
+          }
         }
-        ## update Widget
-        UpdateFileofCaseWidget()
+    }
+  }
+  FileofCaseWidgetMenu[[gettext("Delete Selected File(s)", domain = "R-RQDA")]]$handler <- function(h,...){
+    if (is_projOpen(envir=.rqda,conName="qdacon")) {
+      SelectedFile <- svalue(.rqda$.FileofCase)
+      Encoding(SelectedFile) <- "UTF-8"
+      for (i in SelectedFile){
+        fid <- dbGetQuery(.rqda$qdacon, sprintf("select id from source where name='%s'",i))$id
+        dbGetQuery(.rqda$qdacon, sprintf("update source set status=0 where name='%s'",i))
+        dbGetQuery(.rqda$qdacon, sprintf("update caselinkage set status=0 where fid=%i",fid))
+        dbGetQuery(.rqda$qdacon, sprintf("update treefile set status=0 where fid=%i",fid))
+        dbGetQuery(.rqda$qdacon, sprintf("update coding set status=0 where fid=%i",fid))
+      }
+      .rqda$.FileofCase[] <- setdiff(.rqda$.FileofCase[],SelectedFile)
+    }
+  }
+  FileofCaseWidgetMenu[[gettext("Edit Selected File", domain = "R-RQDA")]]$handler <- function(h,...){
+    EditFileFun(FileNameWidget=.rqda$.FileofCase)
+  }
+  FileofCaseWidgetMenu[[gettext("File Memo", domain = "R-RQDA")]]$handler <- function(h,...){
+    MemoWidget(gettext("File", domain = "R-RQDA"),.rqda$.FileofCase,"source")
+  }
+  FileofCaseWidgetMenu[[gettext("Rename selected File", domain = "R-RQDA")]]$handler <- function(h,...){
+    if (is_projOpen(envir=.rqda,conName="qdacon")) {
+      selectedFN <- svalue(.rqda$.FileofCase)
+      if (length(selectedFN)==0){
+        gmessage(gettext("Select a file first.", domain = "R-RQDA"),icon="error",con=TRUE)
+      }
+      else {
+        NewFileName <- ginput(gettext("Enter new file name. ", domain = "R-RQDA"),text=selectedFN, icon="info")
+        if (!is.na(NewFileName)) {
+          Encoding(NewFileName) <- "UTF-8"
+          rename(selectedFN,NewFileName,"source")
+          Fnames <- .rqda$.FileofCase[]
+          Fnames[Fnames==selectedFN] <- NewFileName
+          .rqda$.FileofCase[] <- Fnames
+        }
+  }}}
+  FileofCaseWidgetMenu[[gettext("Search Files within Selected Case", domain = "R-RQDA")]]$handler <- function(h, ...) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
+      pattern <- ifelse(is.null(.rqda$lastsearch),"file like '%%'",.rqda$lastsearch)
+      pattern <- ginput(gettext("Please input a search pattern.", domain = "R-RQDA"),text=pattern)
+      if (!is.na(pattern)){
+        Fid <- GetFileId("case")
+        tryCatch(SearchFiles(pattern,Fid=Fid,Widget=".FileofCase",is.UTF8=TRUE),error=function(e) gmessage(gettext("Error~~~.", domain = "R-RQDA")),con=TRUE)
+        assign("lastsearch",pattern,envir=.rqda)
       }
     }
   }
-}
-FileofCaseWidgetMenu$"Delete Selected File(s)"$handler <- function(h,...){
+  FileofCaseWidgetMenu[[gettext("Show ...", domain = "R-RQDA")]][[gettext("Show All by Sorted by Imported Time", domain = "R-RQDA")]]$handler <- function(h,...){
+    ## UpdateFileofCaseWidget()
     if (is_projOpen(envir=.rqda,conName="qdacon")) {
-        SelectedFile <- svalue(.rqda$.FileofCase)
-        Encoding(SelectedFile) <- "UTF-8"
-        for (i in SelectedFile){
-            fid <- dbGetQuery(.rqda$qdacon, sprintf("select id from source where name='%s'",i))$id
-            dbGetQuery(.rqda$qdacon, sprintf("update source set status=0 where name='%s'",i))
-            dbGetQuery(.rqda$qdacon, sprintf("update caselinkage set status=0 where fid=%i",fid))
-            dbGetQuery(.rqda$qdacon, sprintf("update treefile set status=0 where fid=%i",fid))
-            dbGetQuery(.rqda$qdacon, sprintf("update coding set status=0 where fid=%i",fid))
-        }
-        .rqda$.FileofCase[] <- setdiff(.rqda$.FileofCase[],SelectedFile)
+      fid <- GetFileId(condition="case",type="all")
+      FileNameWidgetUpdate(FileNamesWidget=.rqda$.FileofCase,FileId=fid)
     }
-}
-FileofCaseWidgetMenu$"Edit Selected File"$handler <- function(h,...){
-  EditFileFun(FileNameWidget=.rqda$.FileofCase)
-}
-FileofCaseWidgetMenu$"File Memo"$handler <- function(h,...){
-  MemoWidget("File",.rqda$.FileofCase,"source")
-}
-FileofCaseWidgetMenu$"Rename selected File"$handler <- function(h,...){
+  }
+  FileofCaseWidgetMenu[[gettext("Show ...", domain = "R-RQDA")]][[gettext("Show Coded Files Only (sorted)", domain = "R-RQDA")]]$handler <- function(h,...){
     if (is_projOpen(envir=.rqda,conName="qdacon")) {
-        selectedFN <- svalue(.rqda$.FileofCase)
-        if (length(selectedFN)==0){
-            gmessage("Select a file first.",icon="error",con=TRUE)
-        }
-        else {
-            NewFileName <- ginput("Enter new file name. ",text=selectedFN, icon="info")
-            if (!is.na(NewFileName)) {
-                Encoding(NewFileName) <- "UTF-8"
-                rename(selectedFN,NewFileName,"source")
-                Fnames <- .rqda$.FileofCase[]
-                Fnames[Fnames==selectedFN] <- NewFileName
-                .rqda$.FileofCase[] <- Fnames
-            }
-        }}}
-FileofCaseWidgetMenu$"Search Files within Seleted Case"$handler <- function(h, ...) {
-    if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
-        pattern <- ifelse(is.null(.rqda$lastsearch),"file like '%%'",.rqda$lastsearch)
-        pattern <- ginput("Please input a search pattern.",text=pattern)
-        if (!is.na(pattern)){
-            Fid <- GetFileId("case")
-            tryCatch(SearchFiles(pattern,Fid=Fid,Widget=".FileofCase",is.UTF8=TRUE),error=function(e) gmessage("Error~~~."),con=TRUE)
-            assign("lastsearch",pattern,envir=.rqda)
-        }
+      fid <- GetFileId(condition="case",type="coded")
+      FileNameWidgetUpdate(FileNamesWidget=.rqda$.FileofCase,FileId=fid)
     }
-}
-FileofCaseWidgetMenu$"Show ..."$"Show All by Sorted by Imported Time"$handler <- function(h,...){
-  ## UpdateFileofCaseWidget()
-  if (is_projOpen(envir=.rqda,conName="qdacon")) {
-    fid <- GetFileId(condition="case",type="all")
-    FileNameWidgetUpdate(FileNamesWidget=.rqda$.FileofCase,FileId=fid)
   }
-}
-FileofCaseWidgetMenu$"Show ..."$"Show Coded Files Only (sorted)"$handler <- function(h,...){
-  if (is_projOpen(envir=.rqda,conName="qdacon")) {
-    fid <- GetFileId(condition="case",type="coded")
-    FileNameWidgetUpdate(FileNamesWidget=.rqda$.FileofCase,FileId=fid)
-  }
-}
-FileofCaseWidgetMenu$"Show ..."$"Show Uncoded Files Only (sorted)"$handler <- function(h,...){
-  if (is_projOpen(envir=.rqda,conName="qdacon")) {
-    fid <- GetFileId(condition="case",type="uncoded")
-    FileNameWidgetUpdate(FileNamesWidget=.rqda$.FileofCase,FileId=fid)
-  }
-}
-FileofCaseWidgetMenu$"Show Selected File Property"$handler <- function(h, ...) {
-  if (is_projOpen(env = .rqda, conName = "qdacon", message = FALSE)) {
-    ShowFileProperty(Fid=GetFileId("case","selected"))
+  FileofCaseWidgetMenu[[gettext("Show ...", domain = "R-RQDA")]][[gettext("Show Uncoded Files Only (sorted)", domain = "R-RQDA")]]$handler <- function(h,...){
+    if (is_projOpen(envir=.rqda,conName="qdacon")) {
+      fid <- GetFileId(condition="case",type="uncoded")
+      FileNameWidgetUpdate(FileNamesWidget=.rqda$.FileofCase,FileId=fid)
     }
+  }
+  FileofCaseWidgetMenu[[gettext("Show Selected File Property", domain = "R-RQDA")]]$handler <- function(h, ...) {
+    if (is_projOpen(envir = .rqda, conName = "qdacon", message = FALSE)) {
+      ShowFileProperty(Fid=GetFileId("case","selected"))
+    }
+  }
+  FileofCaseWidgetMenu
 }
 
 ####################
 ## Defunct functions
 ####################
 
-##   AddWebSearchButton <- function(label="WebSearch",CaseNamesWidget=.rqda$.CasesNamesWidget){
+##   AddWebSearchButton <- function(label=gettext("WebSearch", domain = "R-RQDA"),CaseNamesWidget=.rqda$.CasesNamesWidget){
 ##     gbutton(label,handler=function(h,...) {
 ##       if (is_projOpen(envir=.rqda,conName="qdacon")) {
 ##         KeyWord <- svalue(CaseNamesWidget)
@@ -431,14 +440,14 @@ FileofCaseWidgetMenu$"Show Selected File Property"$handler <- function(h, ...) {
 ## }
 
 
-## CaseMemoButton <- function(label="Memo",...){
+## CaseMemoButton <- function(label=gettext("Memo", domain = "R-RQDA"),...){
 ## ## no longer used
 ##   gbutton(label, handler=function(h,...) {
 ##     ## code memo: such as meaning of code etc.
 ##     if (is_projOpen(envir=.rqda,"qdacon")) {
 ##       currentCase <- svalue(.rqda$.CasesNamesWidget)
 ##       if (length(currentCase)==0){
-##         gmessage("Select a Case first.",icon="error",con=TRUE)
+##         gmessage(gettext("Select a Case first.", domain = "R-RQDA"),icon="error",con=TRUE)
 ##       }
 ##       else {
 ##         tryCatch(dispose(.rqda$.casememo),error=function(e) {})
@@ -447,7 +456,7 @@ FileofCaseWidgetMenu$"Show Selected File Property"$handler <- function(h, ...) {
 ##         .casememo <- .rqda$.casememo
 ##         .casememo2 <- gpanedgroup(horizontal = FALSE, con=.casememo)
 ##         currentCase <- enc(currentCase, encoding="UTF-8")
-##         gbutton("Save Case Memo",con=.casememo2,handler=function(h,...){
+##         gbutton(gettext("Save Case Memo", domain = "R-RQDA"),con=.casememo2,handler=function(h,...){
 ##           newcontent <- svalue(W)
 ##           ## Encoding(newcontent) <- "UTF-8"
 ##           newcontent <- enc(newcontent,encoding="UTF-8") ## take care of double quote.
